@@ -35,6 +35,14 @@
 #include <libgit2-glib/ggit-blob-output-stream.h>
 #include <libgit2-glib/ggit-checkout-options.h>
 #include <libgit2-glib/ggit-note.h>
+#include <libgit2-glib/ggit-blame.h>
+#include <libgit2-glib/ggit-cherry-pick-options.h>
+#include <libgit2-glib/ggit-commit.h>
+#include <libgit2-glib/ggit-tree-builder.h>
+#include <libgit2-glib/ggit-remote.h>
+#include <libgit2-glib/ggit-rebase.h>
+#include <libgit2-glib/ggit-blob.h>
+#include <libgit2-glib/ggit-tag.h>
 
 G_BEGIN_DECLS
 
@@ -46,14 +54,11 @@ G_BEGIN_DECLS
 #define GGIT_REPOSITORY_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS ((obj), GGIT_TYPE_REPOSITORY, GgitRepositoryClass))
 
 typedef struct _GgitRepositoryClass	GgitRepositoryClass;
-typedef struct _GgitRepositoryPrivate	GgitRepositoryPrivate;
 
 struct _GgitRepository
 {
 	/*< private >*/
 	GgitNative parent;
-
-	GgitRepositoryPrivate *priv;
 };
 
 /**
@@ -96,10 +101,13 @@ GgitRef            *ggit_repository_lookup_reference  (GgitRepository        *re
                                                        const gchar           *name,
                                                        GError               **error);
 
+GgitRef            *ggit_repository_lookup_reference_dwim  (GgitRepository        *repository,
+                                                            const gchar           *short_name,
+                                                            GError               **error);
+
 GgitRef            *ggit_repository_create_reference  (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GgitOId               *oid,
-                                                       GgitSignature         *signature,
                                                        const gchar           *log_message,
                                                        GError               **error);
 
@@ -107,7 +115,6 @@ GgitRef            *ggit_repository_create_symbolic_reference
                                                       (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        const gchar           *target,
-                                                       GgitSignature         *signature,
                                                        const gchar           *log_message,
                                                        GError               **error);
 
@@ -224,8 +231,6 @@ GgitBranch         *ggit_repository_create_branch     (GgitRepository        *re
                                                        const gchar           *branch_name,
                                                        GgitObject            *target,
                                                        GgitCreateFlags        flags,
-                                                       GgitSignature         *signature,
-                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitBranchEnumerator *ggit_repository_enumerate_branches (GgitRepository        *repository,
@@ -237,6 +242,22 @@ GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *re
                                                        GgitBranchType         branch_type,
                                                        GError               **error);
 
+GgitBlob           *ggit_repository_lookup_blob       (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                             GError         **error);
+
+GgitCommit         *ggit_repository_lookup_commit     (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
+GgitTag            *ggit_repository_lookup_tag        (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
+GgitTree           *ggit_repository_lookup_tree       (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
 GgitRemote         *ggit_repository_lookup_remote     (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GError               **error);
@@ -249,12 +270,31 @@ GgitRemote         *ggit_repository_create_remote     (GgitRepository        *re
 gchar             **ggit_repository_list_remotes      (GgitRepository        *repository,
                                                        GError               **error);
 
+void                ggit_repository_add_remote_push   (GgitRepository        *repository,
+                                                       GgitRemote            *remote,
+                                                       const gchar           *refspec,
+                                                       GError               **error);
+
+void                ggit_repository_add_remote_fetch  (GgitRepository        *repository,
+                                                       GgitRemote            *remote,
+                                                       const gchar           *refspec,
+                                                       GError               **error);
+
 GgitRef            *ggit_repository_get_head          (GgitRepository        *repository,
                                                        GError               **error);
 
+gboolean            ggit_repository_set_head          (GgitRepository        *repository,
+                                                       const gchar           *ref_name,
+                                                       GError               **error);
+
 GFile              *ggit_repository_discover          (GFile                 *location,
                                                        GError               **error);
 
+GFile              *ggit_repository_discover_full     (GFile        *location,
+                                                       gboolean      across_fs,
+                                                       const gchar **ceiling_dirs,
+                                                       GError      **error);
+
 gboolean            ggit_repository_is_head_detached  (GgitRepository        *repository,
                                                        GError               **error);
 
@@ -284,6 +324,11 @@ gboolean            ggit_repository_file_status_foreach
                                                       gpointer                user_data,
                                                       GError                **error);
 
+gboolean            ggit_repository_references_foreach (GgitRepository             *repository,
+                                                        GgitReferencesCallback      callback,
+                                                        gpointer                    user_data,
+                                                        GError                    **error);
+
 gboolean            ggit_repository_references_foreach_name (GgitRepository             *repository,
                                                              GgitReferencesNameCallback  callback,
                                                              gpointer                    user_data,
@@ -304,12 +349,35 @@ gboolean            ggit_repository_submodule_foreach  (GgitRepository
                                                         gpointer                 user_data,
                                                         GError                 **error);
 
+void                ggit_repository_set_submodule_ignore (GgitRepository       *repository,
+                                                          const gchar          *name,
+                                                          GgitSubmoduleIgnore   ignore,
+                                                          GError              **error);
+
+void                ggit_repository_set_submodule_update (GgitRepository       *repository,
+                                                          const gchar          *name,
+                                                          GgitSubmoduleUpdate   update,
+                                                          GError              **error);
+
+void                ggit_repository_set_submodule_url  (GgitRepository          *repository,
+                                                        const gchar             *name,
+                                                        const gchar             *url,
+                                                        GError                 **error);
+
+void                ggit_repository_set_submodule_fetch_recurse (GgitRepository        *repository,
+                                                                 const gchar           *name,
+                                                                 GgitSubmoduleRecurse   fetch_recurse_submodules,
+                                                                 GError               **error);
+
+GgitSubmoduleStatus ggit_repository_get_submodule_status (GgitRepository        *repository,
+                                                          const gchar           *name,
+                                                          GgitSubmoduleIgnore    ignore,
+                                                          GError               **error);
+
 void                ggit_repository_reset              (GgitRepository          *repository,
                                                         GgitObject              *target,
                                                         GgitResetType            reset_type,
                                                         GgitCheckoutOptions     *checkout_options,
-                                                        GgitSignature           *signature,
-                                                        const gchar             *log_message,
                                                         GError                 **error);
 
 void                ggit_repository_reset_default      (GgitRepository          *repository,
@@ -390,7 +458,7 @@ GgitIndex          *ggit_repository_cherry_pick_commit (GgitRepository
                                                         GgitMergeOptions         *merge_options,
                                                         GError                  **error);
 
-const gchar        *ggit_repository_get_default_notes_ref (GgitRepository           *repository,
+gchar              *ggit_repository_get_default_notes_ref (GgitRepository           *repository,
                                                            GError                  **error);
 
 GgitOId            *ggit_repository_create_note        (GgitRepository          *repository,
@@ -419,10 +487,48 @@ gboolean            ggit_repository_note_foreach       (GgitRepository
                                                         GgitNoteCallback         callback,
                                                         gpointer                 user_data,
                                                         GError                 **error);
-gboolean           ggit_repository_path_is_ignored     (GgitRepository          *repository,
+gboolean            ggit_repository_path_is_ignored    (GgitRepository          *repository,
                                                         const gchar             *path,
                                                         GError                 **error);
 
+void                ggit_repository_merge              (GgitRepository          *repository,
+                                                        GgitAnnotatedCommit    **their_heads,
+                                                        gsize                   *their_heads_length,
+                                                        GgitMergeOptions        *merge_opts,
+                                                        GgitCheckoutOptions     *checkout_opts,
+                                                        GError                 **error);
+
+GgitOId            *ggit_repository_merge_base         (GgitRepository          *repository,
+                                                        GgitOId                 *oid_one,
+                                                        GgitOId                 *oid_two,
+                                                        GError                 **error);
+
+GgitIndex          *ggit_repository_merge_trees        (GgitRepository          *repository,
+                                                        GgitTree                *ancestor_tree,
+                                                        GgitTree                *our_tree,
+                                                        GgitTree                *their_tree,
+                                                        GgitMergeOptions        *merge_options,
+                                                        GError                 **error);
+
+GgitIndex          *ggit_repository_merge_commits      (GgitRepository          *repository,
+                                                        GgitCommit              *our_commit,
+                                                        GgitCommit              *their_commit,
+                                                        GgitMergeOptions        *merge_options,
+                                                        GError                 **error);
+
+GgitRebase         *ggit_repository_rebase_init        (GgitRepository       *repository,
+                                                        GgitAnnotatedCommit  *branch,
+                                                        GgitAnnotatedCommit  *upstream,
+                                                        GgitAnnotatedCommit  *onto,
+                                                        GgitRebaseOptions    *options,
+                                                        GError              **error);
+
+GgitRebase         *ggit_repository_rebase_open        (GgitRepository     *repository,
+                                                        GgitRebaseOptions  *options,
+                                                        GError            **error);
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (GgitRepository, g_object_unref)
+
 G_END_DECLS
 
 #endif /* __GGIT_REPOSITORY_H__ */
